tdub.config
--------------

.. currentmodule:: tdub.config

.. automodule:: tdub.config

Constant Summary
^^^^^^^^^^^^^^^^

.. autosummary::

   AVOID_IN_CLF
   AVOID_IN_CLF_1j1b
   AVOID_IN_CLF_2j1b
   AVOID_IN_CLF_2j2b
   DEFAULT_SCAN_PARAMETERS
   FEATURESET_1j1b
   FEATURESET_2j1b
   FEATURESET_2j2b
   PLOTTING_LOGY
   PLOTTING_META_TABLE
   RANDOM_STATE
   SELECTION_1j1b
   SELECTION_2j1b
   SELECTION_2j2b

Function Summary
^^^^^^^^^^^^^^^^

.. autosummary::

   init_meta_table
   init_meta_logy

Constant Reference
^^^^^^^^^^^^^^^^^^

.. autodata:: AVOID_IN_CLF
   :annotation:
.. autodata:: AVOID_IN_CLF_1j1b
   :annotation:
.. autodata:: AVOID_IN_CLF_2j1b
   :annotation:
.. autodata:: AVOID_IN_CLF_2j2b
   :annotation:
.. autodata:: FEATURESET_1j1b
   :annotation:
.. autodata:: FEATURESET_2j1b
   :annotation:
.. autodata:: FEATURESET_2j2b
   :annotation:
.. autodata:: PLOTTING_LOGY
   :annotation:
.. autodata:: PLOTTING_META_TABLE
   :annotation:
.. autodata:: RANDOM_STATE
   :annotation:
.. autodata:: SELECTION_1j1b
   :annotation:
.. autodata:: SELECTION_2j1b
   :annotation:
.. autodata:: SELECTION_2j2b
   :annotation:


Function Reference
^^^^^^^^^^^^^^^^^^

.. autofunction:: init_meta_table
.. autofunction:: init_meta_logy
